==> huaweicloudsdkcfw-3.1.13-py2.py3-none-any.whl: huaweicloudsdkcfw/v1/model/list_ips_protect_mode_using_post_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListIpsProtectModeUsingPostResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'object_id': 'str',
        'status': 'int'
    }

    attribute_map = {
        'object_id': 'object_id',
        'status': 'status'
    }

    def __init__(self, object_id=None, status=None):
        """ListIpsProtectModeUsingPostResponse

        The model defined in huaweicloud sdk

        :param object_id: 防护对象id
        :type object_id: str
        :param status: 防护状态
        :type status: int
        """
        
        super(ListIpsProtectModeUsingPostResponse, self).__init__()

        self._object_id = None
        self._status = None
        self.discriminator = None

        if object_id is not None:
            self.object_id = object_id
        if status is not None:
            self.status = status

    @property
    def object_id(self):
        """Gets the object_id of this ListIpsProtectModeUsingPostResponse.

        防护对象id

        :return: The object_id of this ListIpsProtectModeUsingPostResponse.
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this ListIpsProtectModeUsingPostResponse.

        防护对象id

        :param object_id: The object_id of this ListIpsProtectModeUsingPostResponse.
        :type object_id: str
        """
        self._object_id = object_id

    @property
    def status(self):
        """Gets the status of this ListIpsProtectModeUsingPostResponse.

        防护状态

        :return: The status of this ListIpsProtectModeUsingPostResponse.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ListIpsProtectModeUsingPostResponse.

        防护状态

        :param status: The status of this ListIpsProtectModeUsingPostResponse.
        :type status: int
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListIpsProtectModeUsingPostResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcfw-3.1.20-py2.py3-none-any.whl: huaweicloudsdkcfw/v1/model/list_ips_protect_mode_using_post_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListIpsProtectModeUsingPostResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'object_id': 'str',
        'status': 'int'
    }

    attribute_map = {
        'object_id': 'object_id',
        'status': 'status'
    }

    def __init__(self, object_id=None, status=None):
        """ListIpsProtectModeUsingPostResponse

        The model defined in huaweicloud sdk

        :param object_id: 防护对象id，是创建云防火墙后用于区分互联网边界防护和VPC边界防护的标志id，可通过调用查询防火墙实例接口获得，注意type为0的为互联网边界防护对象id，type为1的为VPC边界防护对象id。具体可参考APIExlorer和帮助中心FAQ。
        :type object_id: str
        :param status: 防护状态
        :type status: int
        """
        
        super(ListIpsProtectModeUsingPostResponse, self).__init__()

        self._object_id = None
        self._status = None
        self.discriminator = None

        if object_id is not None:
            self.object_id = object_id
        if status is not None:
            self.status = status

    @property
    def object_id(self):
        """Gets the object_id of this ListIpsProtectModeUsingPostResponse.

        防护对象id，是创建云防火墙后用于区分互联网边界防护和VPC边界防护的标志id，可通过调用查询防火墙实例接口获得，注意type为0的为互联网边界防护对象id，type为1的为VPC边界防护对象id。具体可参考APIExlorer和帮助中心FAQ。

        :return: The object_id of this ListIpsProtectModeUsingPostResponse.
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this ListIpsProtectModeUsingPostResponse.

        防护对象id，是创建云防火墙后用于区分互联网边界防护和VPC边界防护的标志id，可通过调用查询防火墙实例接口获得，注意type为0的为互联网边界防护对象id，type为1的为VPC边界防护对象id。具体可参考APIExlorer和帮助中心FAQ。

        :param object_id: The object_id of this ListIpsProtectModeUsingPostResponse.
        :type object_id: str
        """
        self._object_id = object_id

    @property
    def status(self):
        """Gets the status of this ListIpsProtectModeUsingPostResponse.

        防护状态

        :return: The status of this ListIpsProtectModeUsingPostResponse.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ListIpsProtectModeUsingPostResponse.

        防护状态

        :param status: The status of this ListIpsProtectModeUsingPostResponse.
        :type status: int
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListIpsProtectModeUsingPostResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
